# Matt's new, improved, massive .tcshrc
# DO NOT EDIT THIS FILE!
# This file should never need changing on a per-system basis.
set TCSHRC_VERSION="3.0.0"

# Flippable settings in local/conf.tcsh; see default.conf.tcsh for
# available choicse and defaults.
# Local settings in various files under local/.  Names checked:
#
# local.tcsh
# $user.tcsh
# $HOST.tcsh
# $HOSTNAME.tcsh
# $user@$HOST.tcsh
# $user@$HOSTNAME.tcsh
#
# And finally, stuff in local/autoload/ is mass-source'd.
#
# If that ain't enough flexibility for you, you've got Problems(tm).

# Allow relocating this and its internals
if( ! ${?tcshrc_dir} ) then
	set tcshrc_dir="~/.tcsh"
endif

# Allow relocating local.  Prefer ~/.tcsh/local if it exists, else accept
# ~/.tcsh.local
if( ! ${?tcshrc_local_dir} ) then
	foreach dir ("${tcshrc_dir}/local" "~/.tcsh.local")
		if( -d ${dir} ) then
			set tcshrc_local_dir = $dir
			break
		endif
	end
	unset dir

	# Fallback
	if( ! ${?tcshrc_local_dir} ) then
		set tcshrc_local_dir = "${tcshrc_dir}/local"
	endif
endif

# First, setup a reasonable lookin' around environment
set path=(/usr/{sbin,bin} /{sbin,bin})

# Aliases for loading our pieces
alias tcshdir_source 'source ${tcshrc_dir}/\!:1 \!:2*'
alias tcshdir_source_cond 'tcshdir_source source_conditional.tcsh ${tcshrc_dir}/\!:1 \!:2*'

# We'll leave this alias defined, so that user code can invoke it later
# to [re-]source files in local/.
alias tcshrc_local 'tcshdir_source source_conditional.tcsh ${tcshrc_local_dir}/\!:1.tcsh \!:2*'

# See what OS we're running
tcshdir_source os_detect.tcsh

# Load default config
tcshdir_source_cond default.conf.tcsh
if( ! ${?_tcshrc_bs_send} ) then
	# Randomly chosen param
	echo "Warning: can't find default.conf.tcsh, you're in trouble..."
endif

# Load user overrides
tcshrc_local conf



#
# OS dependent setup first...
#

# Path settings (some OS dependent, some not, but do it right away)
tcshdir_source paths.tcsh

# OS dependent aliases
tcshdir_source os_aliases.tcsh

# Figuring out the EUID _may_ be OS dependent.  I guess _teeechnically_,
# you could set it in the conf if we somehow failed getting it
# otherwise...
if( ! ${?_tcshrc_euid} ) then
	if( ${?euid} ) then
		# As of tcsh 6.18.0 (2012), this is around by default, so that's
		# probably _usually_ the case for us now.
		set _tcshrc_euid=${euid}
	else
		# This means an old tcsh, so take our best guess
		tcshdir_source os_euid.tcsh
	endif
endif



#
# Done OS dependent, now the normal setup
#

# Set special config vars
tcshdir_source special_vars.tcsh

# Aliases
tcshdir_source aliases.tcsh

# Default completions
tcshdir_source completions.tcsh

# Set some env's
tcshdir_source setenv.tcsh

# Gotta make sure we have some bindings right...
tcshdir_source bindings.tcsh

# Save/restore state if we have a state dir defined.
if( ${?_tcshrc_state_dir} ) then
	tcshdir_source state_dir.tcsh
endif

# Stuff that only makes sense on tty's
if( "$tty" != "" ) then
	tcshdir_source if_tty.tcsh
endif

# Set the umask
tcshdir_source umask.tcsh

# Now, the prompt...
tcshdir_source prompt.tcsh



#
# Local changes/overrides.  These should remain the last functional
# things in the file, since we want local specific config to be able to
# override anything in here.
#

# local.tcsh
tcshrc_local local

# Our username
tcshrc_local $user

# HOST is set by tcsh, we work from that.
# This should work.  cut(1) would be nicer, but I tried it once and it
# failed on some system (can't remember which), so...
set _tcshrc_hostname=`echo $HOST | awk -F\. '{print $1}'`

# Full host/domain, then bare host
tcshrc_local $HOST
tcshrc_local $_tcshrc_hostname

# By-user variants of above
tcshrc_local $user@$HOST
tcshrc_local $user@$_tcshrc_hostname

# Grab everything in autoload dir
set __alfiles=`echo -n ${tcshrc_local_dir}/autoload/*.tcsh >& /dev/null`
if( ! ${status} ) then
	foreach i (${tcshrc_local_dir}/autoload/*.tcsh)
		source ${i}
	end
	unset i
endif
unset __alfiles




#
# Now some wrapup bits
#

# Raise the roof
# unlimit -f requires tcsh 6.04, which is from 1993.  I no longer care
# about stuff before that...
unlimit -f


# Warn if we don't know what system we're on.
if( "$tty" != "" ) then
	if( "$_tcshrc_runos" == "UNKNOWN") then
		echo Warning: OS type not recognized, basic settings used
	endif
endif


# Clear cruft out of the environment
unset _tcshrc_*


# Done
